@@ -9,10 +9,11 @@
     © [Lúcuma labs] (http://lucumalabs.com).
 
 """
-from .form import Form, FormSet
+from .form import Form
+from .formset import FormSet
 from .fields import *
 from .validators import *
 from .utils import Markup, get_html_attrs, to_unicode
 
-__version__ = '2.1'
+__version__ = '2.3'
 
