@@ -34,6 +34,13 @@ def test_render_collection():
     assert (field(required=False) ==
             u'<input name="abc" type="text" value="a, b">')
 
+    field = f.Collection()
+    field.name = u'abc'
+    field.load_data([])
+    assert field() == u'<input name="abc" type="text" value="">'
+    field.load_data([], [])
+    assert field() == u'<input name="abc" type="text" value="">'
+
 
 def test_validate_collection():
     field = f.Collection()
@@ -54,6 +61,9 @@ def test_validate_collection():
     assert field.validate() == None
     assert field.error
 
+    field.load_data(obj_value=[u'a', u'b'])
+    assert field.validate() == [u'a', u'b']
+
 
 def test_filter_collection():
     def filter_the_b(py_value):
@@ -64,6 +74,11 @@ def test_filter_collection():
     field.load_data(u'a, b,c')
     assert field.validate() == [u'a', u'c']
 
+    field = f.Collection(filters=[f.ValidEmail])
+    field.name = 'abc'
+    field.load_data([u'a@example.com,b@example.com'])
+    assert field.validate() == [u'a@example.com', u'b@example.com']
+
 
 def test_render_select():
     items = [(1, u'A'), (2, u'B'), (3, u'C'), (4, u'D'), (5, u'E'),
@@ -153,7 +168,7 @@ def test_render_multiselect():
              (6, u'F'), (7, u'G'),]
     field = f.MultiSelect(items=items)
     field.name = 'abc'
-    field.load_data(obj_value=[2,4,6])
+    field.load_data(str_value=[], obj_value=[2,4,6])
 
     assert unicode(field) == field() == field.as_select()
     expected = (
